pub trait ToSyn {
type Output;
// Required method
fn to_syn(&self) -> Result<Self::Output, ToSynError>;
}Expand description
Trait for converting Pure types back to syn types.
All conversions are fallible because they may involve syn::parse_str
for Other variants (expressions, types, patterns stored as strings).
Required Associated Types
Required Methods
Sourcefn to_syn(&self) -> Result<Self::Output, ToSynError>
fn to_syn(&self) -> Result<Self::Output, ToSynError>
Convert self back into its syn representation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".